==> deepin-qt6integration-debug-6.0.18-2-x86_64.pkg.tar.zst: usr/src/debug/deepin-qt6integration/qt6integration/styleplugins/chameleon/chameleon_autogen/EWIEGA46WW/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // menu_shadow.svg
  0x0,0x0,0x1,0xa6,
  0x3c,
  0x73,0x76,0x67,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3d,0x22,0x68,0x74,0x74,0x70,0x3a,
  0x2f,0x2f,0x77,0x77,0x77,0x2e,0x77,0x33,0x2e,0x6f,0x72,0x67,0x2f,0x32,0x30,0x30,
  0x30,0x2f,0x73,0x76,0x67,0x22,0x20,0x77,0x69,0x64,0x74,0x68,0x3d,0x22,0x31,0x35,
  0x35,0x22,0x20,0x68,0x65,0x69,0x67,0x68,0x74,0x3d,0x22,0x38,0x22,0x20,0x76,0x69,
  0x65,0x77,0x42,0x6f,0x78,0x3d,0x22,0x30,0x20,0x30,0x20,0x31,0x35,0x35,0x20,0x38,
  0x22,0x3e,0xa,0x20,0x20,0x3c,0x64,0x65,0x66,0x73,0x3e,0xa,0x20,0x20,0x20,0x20,
  0x3c,0x6c,0x69,0x6e,0x65,0x61,0x72,0x47,0x72,0x61,0x64,0x69,0x65,0x6e,0x74,0x20,
  0x69,0x64,0x3d,0x22,0x6d,0x65,0x6e,0x75,0x5f,0x73,0x68,0x61,0x64,0x6f,0x77,0x2d,
  0x61,0x22,0x20,0x78,0x31,0x3d,0x22,0x35,0x30,0x25,0x22,0x20,0x78,0x32,0x3d,0x22,
  0x35,0x30,0x25,0x22,0x20,0x79,0x31,0x3d,0x22,0x30,0x25,0x22,0x20,0x79,0x32,0x3d,
  0x22,0x38,0x31,0x2e,0x30,0x32,0x25,0x22,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,
  0x3c,0x73,0x74,0x6f,0x70,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x3d,0x22,0x30,0x25,
  0x22,0x20,0x73,0x74,0x6f,0x70,0x2d,0x63,0x6f,0x6c,0x6f,0x72,0x3d,0x22,0x23,0x30,
  0x30,0x38,0x31,0x46,0x46,0x22,0x20,0x73,0x74,0x6f,0x70,0x2d,0x6f,0x70,0x61,0x63,
  0x69,0x74,0x79,0x3d,0x22,0x2e,0x32,0x22,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x3c,0x73,0x74,0x6f,0x70,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x3d,0x22,0x31,
  0x30,0x30,0x25,0x22,0x20,0x73,0x74,0x6f,0x70,0x2d,0x63,0x6f,0x6c,0x6f,0x72,0x3d,
  0x22,0x23,0x30,0x30,0x38,0x31,0x46,0x46,0x22,0x20,0x73,0x74,0x6f,0x70,0x2d,0x6f,
  0x70,0x61,0x63,0x69,0x74,0x79,0x3d,0x22,0x30,0x22,0x2f,0x3e,0xa,0x20,0x20,0x20,
  0x20,0x3c,0x2f,0x6c,0x69,0x6e,0x65,0x61,0x72,0x47,0x72,0x61,0x64,0x69,0x65,0x6e,
  0x74,0x3e,0xa,0x20,0x20,0x3c,0x2f,0x64,0x65,0x66,0x73,0x3e,0xa,0x20,0x20,0x3c,
  0x72,0x65,0x63,0x74,0x20,0x77,0x69,0x64,0x74,0x68,0x3d,0x22,0x31,0x35,0x35,0x22,
  0x20,0x68,0x65,0x69,0x67,0x68,0x74,0x3d,0x22,0x31,0x30,0x22,0x20,0x66,0x69,0x6c,
  0x6c,0x3d,0x22,0x75,0x72,0x6c,0x28,0x23,0x6d,0x65,0x6e,0x75,0x5f,0x73,0x68,0x61,
  0x64,0x6f,0x77,0x2d,0x61,0x29,0x22,0x20,0x66,0x69,0x6c,0x6c,0x2d,0x72,0x75,0x6c,
  0x65,0x3d,0x22,0x65,0x76,0x65,0x6e,0x6f,0x64,0x64,0x22,0x2f,0x3e,0xa,0x3c,0x2f,
  0x73,0x76,0x67,0x3e,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // chameleonstyle
  0x0,0xe,
  0xb,0x5d,0x23,0x45,
  0x0,0x63,
  0x0,0x68,0x0,0x61,0x0,0x6d,0x0,0x65,0x0,0x6c,0x0,0x65,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,0x74,0x0,0x79,0x0,0x6c,0x0,0x65,
    // menu_shadow.svg
  0x0,0xf,
  0x0,0x6,0xa9,0x27,
  0x0,0x6d,
  0x0,0x65,0x0,0x6e,0x0,0x75,0x0,0x5f,0x0,0x73,0x0,0x68,0x0,0x61,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,0x2e,0x0,0x73,0x0,0x76,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0x88,0x7b,0xd4,0x88,
  // :/chameleonstyle
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0x88,0x7b,0xd4,0x88,
  // :/chameleonstyle/menu_shadow.svg
  0x0,0x0,0x0,0x22,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0x88,0x7b,0xd4,0x88,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> deepin-qt6integration-debug-6.0.19-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-qt6integration/qt6integration/styleplugins/chameleon/chameleon_autogen/EWIEGA46WW/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // menu_shadow.svg
  0x0,0x0,0x1,0xa6,
  0x3c,
  0x73,0x76,0x67,0x20,0x78,0x6d,0x6c,0x6e,0x73,0x3d,0x22,0x68,0x74,0x74,0x70,0x3a,
  0x2f,0x2f,0x77,0x77,0x77,0x2e,0x77,0x33,0x2e,0x6f,0x72,0x67,0x2f,0x32,0x30,0x30,
  0x30,0x2f,0x73,0x76,0x67,0x22,0x20,0x77,0x69,0x64,0x74,0x68,0x3d,0x22,0x31,0x35,
  0x35,0x22,0x20,0x68,0x65,0x69,0x67,0x68,0x74,0x3d,0x22,0x38,0x22,0x20,0x76,0x69,
  0x65,0x77,0x42,0x6f,0x78,0x3d,0x22,0x30,0x20,0x30,0x20,0x31,0x35,0x35,0x20,0x38,
  0x22,0x3e,0xa,0x20,0x20,0x3c,0x64,0x65,0x66,0x73,0x3e,0xa,0x20,0x20,0x20,0x20,
  0x3c,0x6c,0x69,0x6e,0x65,0x61,0x72,0x47,0x72,0x61,0x64,0x69,0x65,0x6e,0x74,0x20,
  0x69,0x64,0x3d,0x22,0x6d,0x65,0x6e,0x75,0x5f,0x73,0x68,0x61,0x64,0x6f,0x77,0x2d,
  0x61,0x22,0x20,0x78,0x31,0x3d,0x22,0x35,0x30,0x25,0x22,0x20,0x78,0x32,0x3d,0x22,
  0x35,0x30,0x25,0x22,0x20,0x79,0x31,0x3d,0x22,0x30,0x25,0x22,0x20,0x79,0x32,0x3d,
  0x22,0x38,0x31,0x2e,0x30,0x32,0x25,0x22,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,
  0x3c,0x73,0x74,0x6f,0x70,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x3d,0x22,0x30,0x25,
  0x22,0x20,0x73,0x74,0x6f,0x70,0x2d,0x63,0x6f,0x6c,0x6f,0x72,0x3d,0x22,0x23,0x30,
  0x30,0x38,0x31,0x46,0x46,0x22,0x20,0x73,0x74,0x6f,0x70,0x2d,0x6f,0x70,0x61,0x63,
  0x69,0x74,0x79,0x3d,0x22,0x2e,0x32,0x22,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x3c,0x73,0x74,0x6f,0x70,0x20,0x6f,0x66,0x66,0x73,0x65,0x74,0x3d,0x22,0x31,
  0x30,0x30,0x25,0x22,0x20,0x73,0x74,0x6f,0x70,0x2d,0x63,0x6f,0x6c,0x6f,0x72,0x3d,
  0x22,0x23,0x30,0x30,0x38,0x31,0x46,0x46,0x22,0x20,0x73,0x74,0x6f,0x70,0x2d,0x6f,
  0x70,0x61,0x63,0x69,0x74,0x79,0x3d,0x22,0x30,0x22,0x2f,0x3e,0xa,0x20,0x20,0x20,
  0x20,0x3c,0x2f,0x6c,0x69,0x6e,0x65,0x61,0x72,0x47,0x72,0x61,0x64,0x69,0x65,0x6e,
  0x74,0x3e,0xa,0x20,0x20,0x3c,0x2f,0x64,0x65,0x66,0x73,0x3e,0xa,0x20,0x20,0x3c,
  0x72,0x65,0x63,0x74,0x20,0x77,0x69,0x64,0x74,0x68,0x3d,0x22,0x31,0x35,0x35,0x22,
  0x20,0x68,0x65,0x69,0x67,0x68,0x74,0x3d,0x22,0x31,0x30,0x22,0x20,0x66,0x69,0x6c,
  0x6c,0x3d,0x22,0x75,0x72,0x6c,0x28,0x23,0x6d,0x65,0x6e,0x75,0x5f,0x73,0x68,0x61,
  0x64,0x6f,0x77,0x2d,0x61,0x29,0x22,0x20,0x66,0x69,0x6c,0x6c,0x2d,0x72,0x75,0x6c,
  0x65,0x3d,0x22,0x65,0x76,0x65,0x6e,0x6f,0x64,0x64,0x22,0x2f,0x3e,0xa,0x3c,0x2f,
  0x73,0x76,0x67,0x3e,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // chameleonstyle
  0x0,0xe,
  0xb,0x5d,0x23,0x45,
  0x0,0x63,
  0x0,0x68,0x0,0x61,0x0,0x6d,0x0,0x65,0x0,0x6c,0x0,0x65,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,0x74,0x0,0x79,0x0,0x6c,0x0,0x65,
    // menu_shadow.svg
  0x0,0xf,
  0x0,0x6,0xa9,0x27,
  0x0,0x6d,
  0x0,0x65,0x0,0x6e,0x0,0x75,0x0,0x5f,0x0,0x73,0x0,0x68,0x0,0x61,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,0x2e,0x0,0x73,0x0,0x76,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x93,0x8f,0xd8,0xb,0xe8,
  // :/chameleonstyle
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x93,0x8f,0xd8,0xb,0xe8,
  // :/chameleonstyle/menu_shadow.svg
  0x0,0x0,0x0,0x22,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x93,0x8f,0xd8,0xb,0xe8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
